@@ -42,7 +42,7 @@ require(tergm)    # dynamic ergm simulations
 ### code chunk number 6: loading_data
 ###################################################
 data("florentine") # an example network
-plot(flobusiness,displaylabels=T)
+plot(flobusiness,displaylabels=TRUE)
 
 
 ###################################################
@@ -50,7 +50,7 @@ plot(flobusiness,displaylabels=T)
 ###################################################
 theta.diss <- log(9)
 stergm.fit.1 <- stergm(flobusiness,
-  formation= ~edges+gwesp(0,fixed=T), 
+  formation= ~edges+gwesp(0,fixed=TRUE), 
   dissolution = ~offset(edges),
 	targets="formation",
   offset.coef.diss = theta.diss,	
@@ -65,7 +65,16 @@ stergm.sim.1 <- simulate.stergm(stergm.fit.1,
 
 
 ###################################################
-### code chunk number 9: calc_params
+### code chunk number 9: mdsj_actual_download
+###################################################
+# the command below will default to not installing MDSJ in a non-interactive session
+# so to make sure it is installed for this sweave build, call it internally
+mdsj.dir <- file.path(path.package("ndtv"), "java/")
+ndtv:::install.mdsj(mdsj.dir)
+
+
+###################################################
+### code chunk number 10: calc_params
 ###################################################
 slice.par<-list(start=75,end=100,interval=1, 
                 aggregate.dur=1,rule="latest")
@@ -74,35 +83,50 @@ compute.animation(stergm.sim.1,slice.par=slice.par,
 
 
 ###################################################
-### code chunk number 10: render.par_animation
+### code chunk number 11: render.par_animation
 ###################################################
-render.par=list(tween.frames=5,show.time=T,
-                show.stats="~edges+gwesp(0,fixed=T)")
+render.par=list(tween.frames=5,show.time=TRUE,
+                show.stats="~edges+gwesp(0,fixed=TRUE)")
 
 
 ###################################################
-### code chunk number 11: render_animation
+### code chunk number 12: render_animation
 ###################################################
 render.animation(stergm.sim.1,render.par=render.par,
-                 edge.col="darkgray",displaylabels=T,
+                 edge.col="darkgray",displaylabels=TRUE,
                  label.cex=.6,label.col="blue")
 
 
 ###################################################
-### code chunk number 12: replay_animation (eval = FALSE)
+### code chunk number 13: replay_animation (eval = FALSE)
 ###################################################
 ## ani.replay()
 
 
 ###################################################
-### code chunk number 13: save_test
+### code chunk number 14: save_test
 ###################################################
 saveVideo(ani.replay(),video.name="stergm.sim.1.mp4", 
                     other.opts="-b 5000k",clean=TRUE)
 
 
 ###################################################
-### code chunk number 14: ndtv.Rnw:163-171
+### code chunk number 15: save_html
+###################################################
+render.d3movie(stergm.sim.1,render.par=render.par,
+                 edge.col="darkgray",displaylabels=TRUE,
+                 label.cex=.6,label.col="blue",
+                filename='stergm.sim1.html')
+
+
+###################################################
+### code chunk number 16: filmstrip
+###################################################
+filmstrip(stergm.sim.1,displaylabels=FALSE)
+
+
+###################################################
+### code chunk number 17: ndtv.Rnw:201-209
 ###################################################
 data(McFarland_cls33_10_16_96)
 slice.par<-list(start=0,end=30,interval=2.5, 
@@ -115,13 +139,13 @@ ani.replay()
 
 
 ###################################################
-### code chunk number 15: mcfarla_timeline1
+### code chunk number 18: mcfarla_timeline1
 ###################################################
 timeline(cls33_10_16_96,slice.par=slice.par)
 
 
 ###################################################
-### code chunk number 16: ndtv.Rnw:182-189
+### code chunk number 19: ndtv.Rnw:220-227
 ###################################################
 slice.par<-list(start=0,end=30,interval=2.5, 
                 aggregate.dur=2.5,rule="latest")
@@ -133,7 +157,7 @@ ani.replay()
 
 
 ###################################################
-### code chunk number 17: ndtv.Rnw:194-202
+### code chunk number 20: ndtv.Rnw:232-240
 ###################################################
 slice.par<-list(start=0,end=30,interval=1, 
                 aggregate.dur=5,rule="latest")
@@ -146,7 +170,13 @@ ani.replay()
 
 
 ###################################################
-### code chunk number 18: define_layout
+### code chunk number 21: gv_options
+###################################################
+layout.par=list(gv.engine='dot',gv.args='-Grankdir=LR') 
+
+
+###################################################
+### code chunk number 22: define_layout
 ###################################################
 network.layout.animate.circle <- function(net, dist.mat = NULL, 
         default.dist = NULL, seed.coords = NULL, layout.par = list(),
@@ -160,7 +190,7 @@ network.layout.animate.circle <- function(net, dist.mat = NULL,
 
 
 ###################################################
-### code chunk number 19: demo_layout
+### code chunk number 23: demo_layout
 ###################################################
 stergm.sim.1<-compute.animation(stergm.sim.1,
               slice.par=slice.par,animation.mode='circle')
@@ -169,7 +199,7 @@ ani.replay()
 
 
 ###################################################
-### code chunk number 20: windsurfers
+### code chunk number 24: windsurfers
 ###################################################
 data(windsurfers)
 slice.par<-list(start=1,end=31,interval=1, 
@@ -186,7 +216,7 @@ ani.replay()
 
 
 ###################################################
-### code chunk number 21: windsurfers
+### code chunk number 25: windsurfers
 ###################################################
 slice.par<-list(start=0,end=24,interval=1, 
                 aggregate.dur=7,rule="latest")
@@ -202,7 +232,7 @@ ani.replay()
 
 
 ###################################################
-### code chunk number 22: color_wheel
+### code chunk number 26: color_wheel
 ###################################################
 activate.edge.attribute(wheel,'width',1,onset=0,terminus=3) 
 activate.edge.attribute(wheel,'width',5,onset=3,terminus=7)
@@ -210,14 +240,14 @@ activate.edge.attribute(wheel,'width',10,onset=3,terminus=Inf)
 
 
 ###################################################
-### code chunk number 23: color_wheel2
+### code chunk number 27: color_wheel2
 ###################################################
 activate.vertex.attribute(wheel,'mySize',1, onset=-Inf,terminus=Inf)
 activate.vertex.attribute(wheel,'mySize',3, onset=5,terminus=10,v=4:8)
 
 
 ###################################################
-### code chunk number 24: color_wheel3
+### code chunk number 28: color_wheel3
 ###################################################
 activate.vertex.attribute(wheel,'color','gray',onset=-Inf,terminus=Inf)
 activate.vertex.attribute(wheel,'color','red',onset=5,terminus=6,v=4)
@@ -227,7 +257,7 @@ activate.vertex.attribute(wheel,'color','pink',onset=8,terminus=9,v=7)
 
 
 ###################################################
-### code chunk number 25: color_wheel4
+### code chunk number 29: color_wheel4
 ###################################################
 render.animation(wheel,edge.lwd='width',vertex.cex='mySize',
                  vertex.col='color',verbose=FALSE)
@@ -235,7 +265,7 @@ ani.replay()
 
 
 ###################################################
-### code chunk number 26: wheel_color_function
+### code chunk number 30: wheel_color_function
 ###################################################
 render.animation(wheel,edge.lwd=3, 
     edge.col=function(slice){rgb((slice%e%'width')/10,0,0)},
@@ -244,7 +274,7 @@ ani.replay()
 
 
 ###################################################
-### code chunk number 27: wheel_betweeness_function
+### code chunk number 31: wheel_betweeness_function
 ###################################################
 require(sna)
 wheel%n%'slice.par'<-list(start=1,end=10,interval=1, 
@@ -256,7 +286,7 @@ ani.replay()
 
 
 ###################################################
-### code chunk number 28: wheel_zoom
+### code chunk number 32: wheel_zoom
 ###################################################
 render.animation(wheel,
       xlim=function(onset){c(-5/(onset*.5),5/(onset*.5))},
@@ -266,7 +296,68 @@ ani.replay()
 
 
 ###################################################
-### code chunk number 29: foo
+### code chunk number 33: short_stergm_prox
+###################################################
+data(short.stergm.sim)  # load a short example dataset of the flomarriage simulation
+proximity.timeline(short.stergm.sim,mode='sammon',
+                   default.dist=10,
+                   labels.at=c(1,16,25),
+                   label.cex=0.7,
+                   vertex.col=c(rep('gray',14),'green','blue') )
+
+
+###################################################
+### code chunk number 34: toy_epi_sim_prox
+###################################################
+data(toy_epi_sim)
+# set up layout to draw plots under timeline
+layout(matrix(c(1,1,1,2,3,4),nrow=2,ncol=3,byrow=TRUE))
+# plot a proximity.timeline illustrating infection spread
+proximity.timeline(toy_epi_sim,vertex.col = 'ndtvcol',
+                   spline.style='color.attribute',
+                   mode = 'sammon',default.dist=100,
+                   chain.direction='reverse')
+# plot 3 static cross-sectional networks 
+# (beginning, middle and end) underneath for comparison
+plot(network.collapse(toy_epi_sim,at=1),vertex.col='ndtvcol',
+     vertex.cex=2,main='toy_epi_sim network at t=1')
+plot(network.collapse(toy_epi_sim,at=17),vertex.col='ndtvcol',
+     vertex.cex=2,main='toy_epi_sim network at=17')
+plot(network.collapse(toy_epi_sim,at=25),vertex.col='ndtvcol',
+     vertex.cex=2,main='toy_epi_sim network at t=25')
+layout(1)
+
+
+###################################################
+### code chunk number 35: windsurfer_timeline
+###################################################
+timeline(windsurfers,plot.edge.spells = FALSE)
+
+
+###################################################
+### code chunk number 36: windsurfer_prox_gaps
+###################################################
+proximity.timeline(windsurfers,start=20,end=31,mode='sammon',
+                   spline.style='inactive.gaps')
+
+
+###################################################
+### code chunk number 37: windsurfer_prox_ignore
+###################################################
+proximity.timeline(windsurfers,start=20,end=31,
+                   mode='sammon',spline.style='inactive.ignore')
+
+
+###################################################
+### code chunk number 38: windsurfer_prox_ghost
+###################################################
+proximity.timeline(windsurfers,start=20,end=31,mode='sammon',
+                   spline.style='inactive.ghost')
+
+
+
+###################################################
+### code chunk number 39: foo
 ###################################################
 packageAsBibitem <- function(pkgname){
   cite <- citation(package=pkgname)
@@ -284,19 +375,19 @@ packageAsBibitem <- function(pkgname){
 
 
 ###################################################
-### code chunk number 30: ndtv.Rnw:468-469
+### code chunk number 40: ndtv.Rnw:605-606
 ###################################################
  packageAsBibitem('networkDynamic')
 
 
 ###################################################
-### code chunk number 31: ndtv.Rnw:478-479
+### code chunk number 41: ndtv.Rnw:615-616
 ###################################################
  packageAsBibitem('ndtv')
 
 
 ###################################################
-### code chunk number 32: ndtv.Rnw:497-498
+### code chunk number 42: ndtv.Rnw:637-638
 ###################################################
  packageAsBibitem('tergm')
 
